@@ -22,4 +22,4 @@ class Parms(object):
     """Parameters for behavior."""
     DEBUG_ON = False
     DELETE_FILES = True
-    PRINT_PROGRESS_INDICATOR = True
+    PRINT_PROGRESS_INDICATOR = False
